==> v4.4.zip: ocarina/ocarina/body/header/__init__.py <==
# Bryan Schumaker (11/25/2010)

import gtk
import libsaria
from ocarina.body import button
import entry

header = gtk.VBox()
header_body = gtk.HBox()
header_sep  = gtk.HSeparator()

header.pack_start(header_body)
header.pack_start(header_sep)
header.show_all()

def add_button(name, button):
	globals()[name] = button
	header_body.pack_start(button, False, False)

header_body.pack_start(entry.entry)
add_button(  "OPEN", button.open_button(True))
add_button(  "SAVE", button.save_button(True))
add_button("EXPORT", button.export_button(True))

sep = gtk.VSeparator()
sep.show()
header_body.pack_start(sep, False, False)

add_button("UPDATE", button.update_button(True))
add_button( "CLEAR", button.clear_button(True))
add_button(  "GOTO", button.goto_button(True))
add_button("RANDOM", button.random_button(libsaria.prefs.get_pref("libsaria.random"), True))
add_button("VOLUME", button.volume_button(libsaria.prefs.get_pref("libsaria.audio.volume"), True))

#import ocarina
#from ocarina.components import button
#from ocarina.components import entry

#gtk    = ocarina.gtk
#header = None
#bar    = None


#def bar_add(widget, expand = False, fill = False):
	#bar.pack_start(widget, expand, fill)

#def init():
	#global header
	#global bar

	#header = gtk.VBox()
	#bar    = gtk.HBox()
	#sep    = gtk.HSeparator()
	#vsep   = gtk.VSeparator()
	#vsep.show()
	#header.pack_start(bar)
	#header.pack_start(sep)
	#header.show_all()

	#bar_add(entry.FilterEntry(), True, True)
	#bar_add(button.OpenButton())
	#bar_add(button.SaveButton())
	#bar_add(button.ExportButton())
	#bar_add(button.SettingsButton())
	#bar_add(vsep)
	#bar_add(button.UpdateButton())
	#bar_add(button.ClearButton())
	#bar_add(button.GotoButton())
	#bar_add(button.RandomButton())
	#bar_add(button.VolumeButton())
#init()

==> v4.7.zip: ocarina/ocarina/body/header/__init__.py <==
# Bryan Schumaker (11/25/2010)

import gtk
from libsaria import prefs
from ocarina.body import button
import entry

header = gtk.VBox()
header_body = gtk.HBox()
header_sep  = gtk.HSeparator()

header.pack_start(header_body)
header.pack_start(header_sep)
header.show_all()

def add_button(name, button):
	globals()[name] = button
	header_body.pack_start(button, False, False)

header_body.pack_start(entry.entry)
add_button(  "OPEN", button.open_button(True))
add_button(  "SAVE", button.save_button(True))
add_button("EXPORT", button.export_button(True))

sep = gtk.VSeparator()
sep.show()
header_body.pack_start(sep, False, False)

add_button("UPDATE", button.update_button(True))
add_button( "CLEAR", button.clear_button(True))
add_button(  "GOTO", button.goto_button(True))
add_button("RANDOM", button.random_button(prefs.get("libsaria.random"), True))
add_button("VOLUME", button.volume_button(prefs.get("libsaria.audio.volume"), True))

#import ocarina
#from ocarina.components import button
#from ocarina.components import entry

#gtk    = ocarina.gtk
#header = None
#bar    = None


#def bar_add(widget, expand = False, fill = False):
	#bar.pack_start(widget, expand, fill)

#def init():
	#global header
	#global bar

	#header = gtk.VBox()
	#bar    = gtk.HBox()
	#sep    = gtk.HSeparator()
	#vsep   = gtk.VSeparator()
	#vsep.show()
	#header.pack_start(bar)
	#header.pack_start(sep)
	#header.show_all()

	#bar_add(entry.FilterEntry(), True, True)
	#bar_add(button.OpenButton())
	#bar_add(button.SaveButton())
	#bar_add(button.ExportButton())
	#bar_add(button.SettingsButton())
	#bar_add(vsep)
	#bar_add(button.UpdateButton())
	#bar_add(button.ClearButton())
	#bar_add(button.GotoButton())
	#bar_add(button.RandomButton())
	#bar_add(button.VolumeButton())
#init()
